@@ -1,7 +1,7 @@
 #ifndef MAINWINDOW_HPP
 #define MAINWINDOW_HPP
 /*
-    Copyright (c) 2008-10 Qtrac Ltd. All rights reserved.
+    Copyright (c) 2008-11 Qtrac Ltd. All rights reserved.
     This program or module is free software: you can redistribute it
     and/or modify it under the terms of the GNU General Public License
     as published by the Free Software Foundation, either version 2 of
@@ -25,10 +25,12 @@
 
 class QBoxLayout;
 class QComboBox;
+class QGroupBox;
 class QLabel;
 class QLineEdit;
 class QPlainTextEdit;
 class QPushButton;
+class QRadioButton;
 class QScrollArea;
 class QSpinBox;
 class QSplitter;
@@ -66,6 +68,7 @@ private slots:
     void compare();
     void options();
     void about();
+    void help();
     void initialize(const QString &filename1, const QString &filename2);
     void updateUi();
     void updateViews(int index=-1);
@@ -74,10 +77,11 @@ private slots:
     void controlTopLevelChanged(bool floating);
     void actionTopLevelChanged(bool floating);
     void logTopLevelChanged(bool floating);
+    void previousPages();
+    void nextPages();
 
 private:
     enum Difference {NoDifference, TextualDifference, VisualDifference};
-    enum Comparison {TextOld, Text, Appearance};
 
     void createWidgets(const QString &filename1, const QString &filename2);
     void createCentralArea();
@@ -87,7 +91,7 @@ private:
             const PdfDocument &pdf1, const QString &filename2,
             const PdfDocument &pdf2);
     void comparePrepareUi();
-    void compareUpdateUi(const QPair<int, int> &pair);
+    void compareUpdateUi(const QPair<int, int> &pair, const int millisec);
     int writeFileInfo(const QString &filename);
     void writeLine(const QString &text);
     void writeError(const QString &text);
@@ -102,9 +106,6 @@ private:
     void computeTextHighlights(QPainterPath *highlighted1,
             QPainterPath *highlighted2, const PdfPage &page1,
             const PdfPage &page2, const int DPI);
-    void computeTextHighlightsOld(QPainterPath *highlighted1,
-            QPainterPath *highlighted2, const PdfPage &page1,
-            const PdfPage &page2, const int DPI);
     void computeVisualHighlights(QPainterPath *highlighted1,
         QPainterPath *highlighted2, const QImage &plainImage1,
         const QImage &plainImage2);
@@ -124,16 +125,20 @@ private:
     QLineEdit *pages2LineEdit;
     QLabel *page2Label;
     QScrollArea *area2;
-    QLabel *comparisonLabel;
-    QComboBox *comparisonComboBox;
+    QGroupBox *comparisonGroupBox;
+    QRadioButton *compareAppearanceRadioButton;
+    QRadioButton *compareTextRadioButton;
     QLabel *viewDiffLabel;
     QPushButton *compareButton;
     QComboBox *viewDiffComboBox;
+    QPushButton *previousButton;
+    QPushButton *nextButton;
     QLabel *statusLabel;
     QLabel *zoomLabel;
     QSpinBox *zoomSpinBox;
     QPushButton *optionsButton;
     QPushButton *aboutButton;
+    QPushButton *helpButton;
     QPushButton *quitButton;
     QPlainTextEdit *logEdit;
     QSplitter *splitter;
